==> mingw-w64-i686-arrow-8.0.0-1-any.pkg.tar.zst: mingw32/lib/cmake/arrow/ArrowPythonFlightTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "arrow_python_flight_shared" for configuration "RELEASE"
set_property(TARGET arrow_python_flight_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(arrow_python_flight_shared PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_python_flight.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libarrow_python_flight.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS arrow_python_flight_shared )
list(APPEND _IMPORT_CHECK_FILES_FOR_arrow_python_flight_shared "${_IMPORT_PREFIX}/lib/libarrow_python_flight.dll.a" "${_IMPORT_PREFIX}/bin/libarrow_python_flight.dll" )

# Import target "arrow_python_flight_static" for configuration "RELEASE"
set_property(TARGET arrow_python_flight_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(arrow_python_flight_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_python_flight.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS arrow_python_flight_static )
list(APPEND _IMPORT_CHECK_FILES_FOR_arrow_python_flight_static "${_IMPORT_PREFIX}/lib/libarrow_python_flight.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-i686-arrow-9.0.0-4-any.pkg.tar.zst: mingw32/lib/cmake/arrow/ArrowPythonFlightTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "arrow_python_flight_shared" for configuration "RELEASE"
set_property(TARGET arrow_python_flight_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(arrow_python_flight_shared PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_python_flight.dll.a"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libarrow_python_flight.dll"
  )

list(APPEND _cmake_import_check_targets arrow_python_flight_shared )
list(APPEND _cmake_import_check_files_for_arrow_python_flight_shared "${_IMPORT_PREFIX}/lib/libarrow_python_flight.dll.a" "${_IMPORT_PREFIX}/bin/libarrow_python_flight.dll" )

# Import target "arrow_python_flight_static" for configuration "RELEASE"
set_property(TARGET arrow_python_flight_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(arrow_python_flight_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_python_flight.a"
  )

list(APPEND _cmake_import_check_targets arrow_python_flight_static )
list(APPEND _cmake_import_check_files_for_arrow_python_flight_static "${_IMPORT_PREFIX}/lib/libarrow_python_flight.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
